@@ -5,10 +5,10 @@
 SL.nnet <- function(Y, X, newX, family, obsWeights, size = 2, ...){
   .SL.require('nnet')
 	if(family$family == "gaussian") {
-		fit.nnet <- nnet(x = X, y = Y, size = size, linout = TRUE, trace = FALSE, maxit = 500, weights = obsWeights)
+		fit.nnet <- nnet::nnet(x = X, y = Y, size = size, linout = TRUE, trace = FALSE, maxit = 500, weights = obsWeights)
 	}
 	if(family$family=="binomial") {
-		fit.nnet <- nnet(x = X, y = Y, size = size, trace = FALSE, maxit = 500, linout = FALSE, weights = obsWeights)
+		fit.nnet <- nnet::nnet(x = X, y = Y, size = size, trace = FALSE, maxit = 500, linout = FALSE, weights = obsWeights)
 	}
 	pred <- predict(fit.nnet, newdata = newX, type = "raw")
 	fit <- list(object = fit.nnet)
